pub struct Diagnostic {
pub severity: Severity,
pub message: String,
pub span: Span,
pub label: Option<String>,
pub notes: Vec<String>,
pub help: Option<String>,
}Fields
severity: Severitymessage: Stringspan: Spanlabel: Option<String>Short text shown under the highlighted span.
notes: Vec<String>help: Option<String>Implementations
Sourceimpl Diagnostic
impl Diagnostic
pub fn error(span: Span, message: impl Into<String>) -> Diagnostic
pub fn warning(span: Span, message: impl Into<String>) -> Diagnostic
pub fn with_label(self, label: impl Into<String>) -> Diagnostic
pub fn with_note(self, note: impl Into<String>) -> Diagnostic
pub fn with_help(self, help: impl Into<String>) -> Diagnostic
Sourcepub fn help(&mut self, help: impl Into<String>) -> &mut Diagnostic
pub fn help(&mut self, help: impl Into<String>) -> &mut Diagnostic
Add help text to a diagnostic that has already been recorded.
Sourcepub fn note(&mut self, note: impl Into<String>) -> &mut Diagnostic
pub fn note(&mut self, note: impl Into<String>) -> &mut Diagnostic
Add a note to a diagnostic that has already been recorded.
pub fn is_error(&self) -> bool
Sourcepub fn render(&self, file: &SourceFile, color: bool) -> String
pub fn render(&self, file: &SourceFile, color: bool) -> String
Render the diagnostic with a source snippet.