pub fn parse_program(src: &str) -> (Program, Vec<Diagnostic>)Expand description
Parse a whole program. Parsing continues after errors, so the program is returned even when there are diagnostics.
pub fn parse_program(src: &str) -> (Program, Vec<Diagnostic>)Parse a whole program. Parsing continues after errors, so the program is returned even when there are diagnostics.