Module token

Module token 

Tokens produced by the lexer.

Structs

Token

Enums

StrPart
A piece of a string literal: plain text, or the source of an interpolated {expression}.
Tok

Functions

is_name
Whether text can be a name in a program: ASCII letters, digits and _, not starting with a digit, and neither a keyword nor a die like d6.
keyword