is_name

Function is_name 

pub fn is_name(text: &str) -> bool
Whether text can be a name in a program: ASCII letters, digits and _, not starting with a digit, and neither a keyword nor a die like d6.